<?php

namespace Drupal\ib_dam\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class IbSettingsForm.
 *
 * Settings form class for module global configuration.
 *
 * @package Drupal\ib_dam\Form
 */
class IbSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ib_dam_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['ib_dam.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('ib_dam.settings');

    $form['debug'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Debug'),
      '#description' => $this->t('Check this setting if you want to have more verbose log messages.'),
      '#default_value' => $config->get('debug'),
    ];

    $form['staging'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Staging'),
      '#description' => $this->t('Check to enable the beta version of the connector browsing interface.'),
      '#default_value' => $config->get('staging'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('ib_dam.settings')
      ->set('debug', $form_state->getValue('debug'))
      ->set('staging', $form_state->getValue('staging'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
